import { create } from 'zustand';
import { persist } from 'zustand/middleware';

export const useCartStore = create(
  persist(
    (set, get) => ({
      cart: [],

      initializeCart: () => {},

      addToCart: (item) => {
        const { cart } = get();
        const existingItem = cart.find((cartItem) => cartItem.id === item.id);

        if (existingItem) {
          const updatedCart = cart.map((cartItem) =>
            cartItem.id === item.id
              ? { ...cartItem, quantity: cartItem.quantity + item.quantity }
              : cartItem
          );
          set({ cart: updatedCart });
        } else {
          set({ cart: [...cart, item] });
        }
      },

      removeFromCart: (id) => {
        const { cart } = get();
        const updatedCart = cart.filter((item) => item.id !== id);
        set({ cart: updatedCart });
      },

      updateQuantity: (id, quantity) => {
        const { cart } = get();
        const updatedCart = cart.map((item) =>
          item.id === id ? { ...item, quantity } : item
        );
        set({ cart: updatedCart });
      },

      clearCart: () => {
        set({ cart: [] });
      },
    }),
    {
      name: 'cart-storage',
    }
  )
);
