import { Button } from '@/components/ui/button';
import {
  Card,
  CardContent,
  CardFooter,
  CardHeader,
  CardTitle,
} from '@/components/ui/card';
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
} from '@/components/ui/table';

export default function CartPage() {
  const cartItems = [
    { id: 1, name: 'Introduction to Psychology Textbook', price: 45 },
    { id: 2, name: 'RHUL Hoodie', price: 30 },
    { id: 3, name: 'Scientific Calculator', price: 15 },
  ];

  const total = cartItems.reduce((sum, item) => sum + item.price, 0);

  return (
    <div className='container mx-auto px-4 py-8'>
      <h1 className='text-4xl font-bold mb-8'>Your Cart</h1>
      <div className='flex flex-col lg:flex-row gap-8'>
        <Card className='flex-grow'>
          <CardHeader>
            <CardTitle>Cart Items</CardTitle>
          </CardHeader>
          <CardContent>
            <Table>
              <TableHeader>
                <TableRow>
                  <TableHead>Item</TableHead>
                  <TableHead>Price</TableHead>
                  <TableHead>Actions</TableHead>
                </TableRow>
              </TableHeader>
              <TableBody>
                {cartItems.map((item) => (
                  <TableRow key={item.id}>
                    <TableCell>{item.name}</TableCell>
                    <TableCell>£{item.price}</TableCell>
                    <TableCell>
                      <Button variant='destructive' size='sm'>
                        Remove
                      </Button>
                    </TableCell>
                  </TableRow>
                ))}
              </TableBody>
            </Table>
          </CardContent>
        </Card>
        <Card className='w-full lg:w-1/3'>
          <CardHeader>
            <CardTitle>Order Summary</CardTitle>
          </CardHeader>
          <CardContent>
            <div className='flex justify-between mb-2'>
              <span>Subtotal:</span>
              <span>£{total}</span>
            </div>
            <div className='flex justify-between mb-4'>
              <span>Estimated Tax:</span>
              <span>£{(total * 0.2).toFixed(2)}</span>
            </div>
            <div className='flex justify-between font-bold'>
              <span>Total:</span>
              <span>£{(total * 1.2).toFixed(2)}</span>
            </div>
          </CardContent>
          <CardFooter>
            <Button className='w-full'>Proceed to Checkout</Button>
          </CardFooter>
        </Card>
      </div>
    </div>
  );
}
